@@ -3,9 +3,9 @@ from argparse import (ArgumentParser, _ArgumentGroup, Namespace,
 import json
 import os
 import pathlib
+import warnings
 from typing import (Any, Collection, Dict, List,
                     Sequence, Tuple, Union, Optional)
-import warnings
 
 import numpy as np
 from pint import UndefinedUnitError
@@ -20,20 +20,74 @@ Unit = ureg.Unit
 
 def force_constants_from_file(filename: Union[str, os.PathLike]
                               ) -> ForceConstants:
-    """
-    Load force constants data from file
+    warnings.warn('force_constants_from_file has been deprecated '
+                  'and will be removed in a future release. Please '
+                  'use load_data_from_file instead',
+                  category=DeprecationWarning,
+                  stacklevel=2)
+    data = load_data_from_file(filename)
+    if not isinstance(data, ForceConstants):
+        raise TypeError('File does not contain force constants')
+    return data
 
-    Parameters
-    ----------
-    filename
-        Data file
 
-    Returns
-    -------
-    fc
-    """
+def modes_from_file(filename: Union[str, os.PathLike]
+                    ) -> Union[QpointPhononModes, QpointFrequencies]:
+    warnings.warn('modes_from_file has been deprecated '
+                  'and will be removed in a future release. Please '
+                  'use load_data_from_file instead',
+                  category=DeprecationWarning,
+                  stacklevel=2)
+    data = load_data_from_file(filename)
+    if not isinstance(data, QpointFrequencies):
+        raise TypeError('File does not contain phonon modes')
+    return data
+
+
+def _load_euphonic_json(filename: Union[str, os.PathLike],
+                        frequencies_only: bool = False
+                        ) -> Union[QpointPhononModes, QpointFrequencies,
+                                   ForceConstants]:
+    with open(filename, 'r') as f:
+        data = json.load(f)
+
+    if 'force_constants' in data:
+        return ForceConstants.from_json_file(filename)
+    elif 'frequencies' in data:
+        if 'eigenvectors' in data and not frequencies_only:
+            return QpointPhononModes.from_json_file(filename)
+        else:
+            return QpointFrequencies.from_json_file(filename)
+    else:
+        raise ValueError("Could not identify Euphonic data in JSON file.")
+
+
+def _load_phonopy_file(filename: Union[str, os.PathLike],
+                       frequencies_only: bool = False
+                       ) -> Union[QpointPhononModes, QpointFrequencies,
+                                  ForceConstants]:
     path = pathlib.Path(filename)
-    if path.suffix in ['.hdf5', '.yaml']:
+    loaded_data = None
+    if not frequencies_only:
+        try:
+            loaded_data = QpointPhononModes.from_phonopy(
+                path=path.parent, phonon_name=path.name)
+        except (KeyError, RuntimeError):
+            # KeyError will be raised if it is actually a force
+            # constants file, RuntimeError will be raised if
+            # it only contains q-point frequencies (no eigenvectors)
+            pass
+
+    # Try to read QpointFrequencies if loading QpointPhononModes has
+    # failed, or has been specifically requested with frequencies_only
+    if frequencies_only or loaded_data is None:
+        try:
+            loaded_data = QpointFrequencies.from_phonopy(
+                path=path.parent, phonon_name=path.name)
+        except KeyError:
+            pass
+
+    if loaded_data is None:
         phonopy_kwargs: Dict[str, Union[str, os.PathLike]] = {}
         phonopy_kwargs['path'] = path.parent
         if (path.parent / 'BORN').is_file():
@@ -53,61 +107,19 @@ def force_constants_from_file(filename: Union[str, os.PathLike]
                 phonopy_kwargs['fc_name'] = 'force_constants.hdf5'
             else:
                 phonopy_kwargs['fc_name'] = 'FORCE_CONSTANTS'
-        return ForceConstants.from_phonopy(**phonopy_kwargs)
-    elif path.suffix in ('.castep_bin', '.check'):
-        return ForceConstants.from_castep(filename)
-    elif path.suffix == '.json':
-        return ForceConstants.from_json_file(filename)
-    else:
-        raise ValueError("File not recognised. Filename should be "
-                         "*.yaml or force_constants.hdf5 (phonopy), "
-                         "*.castep_bin or *.check "
-                         "(castep) or *.json (JSON from Euphonic).")
+        loaded_data = ForceConstants.from_phonopy(**phonopy_kwargs)
+
+    if loaded_data is None:
+        raise ValueError("Could not identify data in Phonopy file.")
+
+    return loaded_data
 
 
-def modes_from_file(filename: Union[str, os.PathLike]
-                    ) -> QpointPhononModes:
-    """
-    Load phonon mode data from file
-
-    Parameters
-    ----------
-    filename
-        Data file
-
-    Returns
-    -------
-    modes
-    """
-    path = pathlib.Path(filename)
-    if path.suffix == '.phonon':
-        return QpointPhononModes.from_castep(path)
-    elif path.suffix == '.json':
-        return QpointPhononModes.from_json_file(path)
-    elif path.suffix in ('.yaml', '.hdf5'):
-        return QpointPhononModes.from_phonopy(path=path.parent,
-                                              phonon_name=path.name)
-    else:
-        raise ValueError("File not recognised. Should have extension "
-                         ".yaml or .hdf5 (phonopy), "
-                         ".phonon (castep) or .json (JSON from Euphonic).")
-
-
-def _load_json(filename: Union[str, os.PathLike]
-               ) -> Union[QpointPhononModes, ForceConstants]:
-    with open(filename, 'r') as f:
-        data = json.load(f)
-
-    if 'force_constants' in data:
-        return force_constants_from_file(filename)
-    elif 'eigenvectors' in data:
-        return modes_from_file(filename)
-    else:
-        raise ValueError("Could not identify Euphonic data in JSON file.")
-
-
-def load_data_from_file(filename: Union[str, os.PathLike]
-                        ) -> Union[QpointPhononModes, ForceConstants]:
+def load_data_from_file(filename: Union[str, os.PathLike],
+                        frequencies_only: bool = False,
+                        verbose: bool = False
+                        ) -> Union[QpointPhononModes, QpointFrequencies,
+                                   ForceConstants]:
     """
     Load phonon mode or force constants data from file
 
@@ -115,34 +127,42 @@ def load_data_from_file(filename: Union[str, os.PathLike]
     ----------
     filename
         The file with a path
+    frequencies_only
+        If true only reads frequencies (not eigenvectors) from the
+        file. Only applies if the file is not a force constants
+        file.
 
     Returns
     -------
     file_data
     """
-    qpoint_phonon_modes_suffixes = ('.phonon')
-    force_constants_suffixes = ('.castep_bin', '.check')
+    castep_qpm_suffixes = ('.phonon',)
+    castep_fc_suffixes = ('.castep_bin', '.check')
+    phonopy_suffixes = ('.hdf5', '.yaml')
 
     path = pathlib.Path(filename)
-    if path.suffix in qpoint_phonon_modes_suffixes:
-        return modes_from_file(path)
-    elif path.suffix in force_constants_suffixes:
-        return force_constants_from_file(path)
+    if path.suffix in castep_qpm_suffixes:
+        if frequencies_only:
+            data = QpointFrequencies.from_castep(path)
+        else:
+            data = QpointPhononModes.from_castep(path)
+    elif path.suffix in castep_fc_suffixes:
+        data = ForceConstants.from_castep(path)
     elif path.suffix == '.json':
-        return _load_json(path)
-    elif path.suffix in ('.hdf5', '.yaml'):
-        try:
-            return modes_from_file(path)
-        except KeyError:
-            return force_constants_from_file(path)
+        data = _load_euphonic_json(path, frequencies_only)
+    elif path.suffix in phonopy_suffixes:
+        data = _load_phonopy_file(path, frequencies_only)
     else:
         raise ValueError(
-            "File format was not recognised. Force constant data for import "
-            f"should have extension from {force_constants_suffixes},"
-            " phonon mode data for import should have extension "
-            f"'{qpoint_phonon_modes_suffixes[0]}',"
-            " data from phonpy should have extension .yaml or .hdf5,"
-            " data from Euphonic should have extension '.json'.")
+            f"File format was not recognised. CASTEP force constants "
+            f"data for import should have extension from "
+            f"{castep_fc_suffixes}, CASTEP phonon mode data for import "
+            f"should have extension '{castep_qpm_suffixes}', data from "
+            f"Phonopy should have extension from {phonopy_suffixes}, "
+            f"data from Euphonic should have extension '.json'.")
+    if verbose:
+        print(f'{data.__class__.__name__} data was loaded')
+    return data
 
 
 def get_args(parser: ArgumentParser, params: Optional[List[str]] = None
@@ -412,6 +432,20 @@ def _arrange_pdos_groups(pdos: Spectrum1DCollection,
     return dos
 
 
+def _plot_label_kwargs(args: Namespace, default_xlabel: str = '',
+                       default_ylabel: str = '') -> Dict[str, str]:
+    """Collect title/label arguments that can be passed to plot_nd
+    """
+    plot_kwargs = dict(title=args.title,
+                       xlabel=default_xlabel,
+                       ylabel=default_ylabel)
+    if args.ylabel is not None:
+        plot_kwargs['ylabel'] = args.ylabel
+    if args.xlabel is not None:
+        plot_kwargs['xlabel'] = args.xlabel
+    return plot_kwargs
+
+
 def _calc_modes_kwargs(args: Namespace) -> Dict[str, Any]:
     """Collect arguments that can be passed to calculate_qpoint_phonon_modes()
     """
@@ -525,7 +559,7 @@ def _get_cli_parser(features: Collection[str] = {}
             help=('Force use of compiled C extension when computing '
                   'phonon frequencies/eigenvectors (or raise error).'))
         use_c.add_argument(
-            '--disable-c', action='store_false', dest='use_c',
+            '--disable-c', action='store_false', dest='use_c', default=None,
             help=('Do not attempt to use compiled C extension when computing '
                   'phonon frequencies/eigenvectors.'))
         sections['performance'].add_argument(
@@ -630,16 +664,45 @@ def _get_cli_parser(features: Collection[str] = {}
                   '"golden" and "random-sphere".'))
 
     if 'plotting' in features:
+        sections['file'].add_argument(
+            '--save-json', dest='save_json', default=None,
+            help='Save spectrum to a .json file with this name')
         section = sections['plotting']
         section.add_argument(
             '-s', '--save-to', dest='save_to', default=None,
             help='Save resulting plot to a file with this name')
         section.add_argument('--title', type=str, default='',
                              help='Plot title')
-        section.add_argument('--x-label', type=str, default=None,
-                             dest='x_label', help='Plot x-axis label')
-        section.add_argument('--y-label', type=str, default=None,
-                             dest='y_label', help='Plot y-axis label')
+        section.add_argument('--x-label', '--xlabel', type=str, default=None,
+                             dest='xlabel', help='Plot x-axis label')
+        section.add_argument('--y-label', '--ylabel', type=str, default=None,
+                             dest='ylabel', help='Plot y-axis label')
+        section.add_argument('--style', type=str, nargs='+',
+                             help='Matplotlib styles (name or file)')
+        section.add_argument('--no-base-style', action='store_true',
+                             dest='no_base_style',
+                             help=('Remove all default formatting before '
+                                   'applying other style options.'))
+        section.add_argument('--font', type=str, default=None,
+                             help=('Select text font. (This has to be a name '
+                                   'known to Matplotlib. font-family will be '
+                                   'set to sans-serif; it doesn\'t matter if)'
+                                   'the font is actually sans-serif.'))
+        section.add_argument('--font-size', '--fontsize', type=float,
+                             default=None, dest='fontsize',
+                             help='Set base font size in pt.')
+        section.add_argument('--fig-size', '--figsize', type=float, nargs=2,
+                             default=None, dest='figsize',
+                             help='Figure canvas size in FIGSIZE-UNITS')
+        section.add_argument('--fig-size-unit', '--figsize-unit', type=str,
+                             default='cm', dest='figsize_unit',
+                             help='Unit of length for --figsize')
+
+    if ('plotting' in features) and not ('map' in features):
+        section = sections['plotting']
+        section.add_argument('--line-width', '--linewidth', type=float,
+                             default=None, dest='linewidth',
+                             help='Set line width in pt.')
 
     if {'ebins', 'q-e'}.intersection(features):
         section = sections['energy']
@@ -661,6 +724,17 @@ def _get_cli_parser(features: Collection[str] = {}
                     help=('Use adaptive broadening on the energy axis to '
                           'broaden based on phonon mode widths, rather than '
                           'using fixed width broadening'))
+                section.add_argument(
+                    '--adaptive-method', type=str, default='reference',
+                    dest='adaptive_method', choices=('reference', 'fast'),
+                    help='The adaptive broadening method')
+                section.add_argument(
+                    '--adaptive-error', type=float, default=0.01,
+                    dest='adaptive_error',
+                    help=('Maximum absolute error '
+                          'for gaussian approximations '
+                          'when using the fast adaptive '
+                          'broadening method'))
                 eb_help = (
                     'If using fixed width broadening, the FWHM of broadening '
                     'on energy axis in ENERGY_UNIT (no broadening if '
@@ -703,13 +777,14 @@ def _get_cli_parser(features: Collection[str] = {}
 
     if 'map' in features:
         sections['plotting'].add_argument(
-            '--v-min', type=float, default=None, dest='v_min',
+            '--v-min', '--vmin', type=float, default=None, dest='vmin',
             help='Minimum of data range for colormap.')
         sections['plotting'].add_argument(
-            '--v-max', type=float, default=None, dest='v_max',
+            '--v-max', '--vmax', type=float, default=None, dest='vmax',
             help='Maximum of data range for colormap.')
         sections['plotting'].add_argument(
-            '--cmap', type=str, default='viridis', help='Matplotlib colormap')
+            '--c-map', '--cmap', type=str, default=None, dest='cmap',
+            help='Matplotlib colormap')
 
     if 'btol' in features:
         sections['q'].add_argument(
@@ -748,3 +823,53 @@ def _get_cli_parser(features: Collection[str] = {}
         )
 
     return parser, sections
+
+
+MplStyle = Union[str, Dict[str, str]]
+
+
+def _compose_style(
+        *, user_args: Namespace, base: Optional[List[MplStyle]]
+        ) -> List[MplStyle]:
+    """Combine user-specified style options with default stylesheets
+
+    Args:
+        user_args: from _get_cli_parser().parse_args()
+        base: Euphonic default styles for this plot
+
+    N.B. matplotlib applies styles from left to right, so the right-most
+    elements of the list take the highest priority. This function builds a
+    list in the order:
+
+    [base style(s), user style(s), CLI arguments]
+    """
+
+    if user_args.no_base_style or base is None:
+        style = []
+    else:
+        style = base
+
+    if user_args.style:
+        style += user_args.style
+
+    # Explicit args take priority over any other
+    explicit_args = {}
+    for user_arg, mpl_property in {'cmap': 'image.cmap',
+                                   'fontsize': 'font.size',
+                                   'font': 'font.sans-serif',
+                                   'linewidth': 'lines.linewidth',
+                                   'figsize': 'figure.figsize'}.items():
+        if getattr(user_args, user_arg, None):
+            explicit_args.update({mpl_property: getattr(user_args, user_arg)})
+
+    if 'font.sans-serif' in explicit_args:
+        explicit_args.update({'font.family': 'sans-serif'})
+
+    if 'figure.figsize' in explicit_args:
+        dimensioned_figsize = [dim * ureg(user_args.figsize_unit)
+                               for dim in explicit_args['figure.figsize']]
+        explicit_args['figure.figsize'] = [dim.to('inches').magnitude
+                                           for dim in dimensioned_figsize]
+
+    style.append(explicit_args)
+    return style
